@@ -9,12 +9,12 @@ from urllib.parse import urlparse, urlunparse
 
 from ryry import store, utils, taskUtils, constant, task
 
-user_token, author = store.get_token_and_authorization()
+g_user_token, g_author = store.get_token_and_authorization()
 def _domain_post(func, params, files={}, timeout=10, domain="api.dalipen.com"):
     headers = {
         'Connection': 'close',
-        'Usertoken': user_token,
-        'Authorization': f"Bearer {author}"
+        'Usertoken': g_user_token,
+        'Authorization': f"Bearer {g_author}"
     }
     url = f"https://{domain}/{func}"
     try:
@@ -44,8 +44,17 @@ def _aigc_post(func, params, files={}, timeout=10):
         return status, msg, data
     return _domain_post(func, params, files, timeout, "aigc.zjtemplate.com")
 
+def checkLicense():
+    req = { }
+    r1, r2, r3 = _aigc_post("aigc/task/checkLicense", req)
+    if r1 != 0:
+        raise Exception(f"check license fail!, reason={r2}")
+    return r3
+
 def set_authorization(author):
     store.save_authorization(author)
+    global g_user_token, g_author
+    g_user_token, g_author = store.get_token_and_authorization()
     if checkLicense():
         print("✅ license check success")
     else:
@@ -103,6 +112,7 @@ def GetTask(widget_list):
         "limit": 1,
         "extend": store.extend()
     }
+    print("====== request gettask: ", req)
     r1, r2, r3 = _aigc_post("aigc/task/getTask", req)
     if r1 != 0:
         return []
