@@ -134,6 +134,15 @@ def enableWidget(widget_id):
         unblock_one(widget_id)
     sp.write(read_data)
     
+def updateWidgetVersion(widget_id, version):
+    sp = Store()
+    read_data = sp.read()
+    if "widgets" not in read_data or not isinstance(read_data["widgets"], dict):
+        read_data["widgets"] = {}
+    widgetsMap = read_data["widgets"]
+    if widget_id in widgetsMap:
+        widgetsMap[widget_id]["version"] = version
+    sp.write(read_data)
 #============================== device id ================================
 
 def writeDeviceInfo(data):
@@ -155,7 +164,7 @@ def extend():
                 _genExtend()
             elif read_data["extend"].get("device_id", "") != read_data.get("deviceInfo", {}).get("device_id", ""):
                 _genExtend()
-            elif read_data["extend"].get("app", "") == "ryry-cli 6.3":
+            elif read_data["extend"].get("app", "") == "ryry-cli 6.8":
                 _genExtend()
         else:
             _genExtend()
@@ -230,4 +239,6 @@ def save_user_token(user_token):
     sp = Store()
     read_data = sp.read()
     read_data["Authorization"] = user_token
-    sp.write(read_data)
\ No newline at end of file
+    sp.write(read_data)
+    
+        
\ No newline at end of file
